@@ -148,10 +148,13 @@ setGeneric(
 #'
 #' Searches rows/columns by name in an array-like object.
 #' @param x An \R object (should be a [`matrix`] or a [`data.frame`]).
-#' @param select A [`function`] to be applied to the row/colum names
-#'  (e.g. [startsWith()]). Must return a single `integer` or `logical` vector.
+#' @param select A [`function`] to be applied to the row/column names
+#'  (e.g. [startsWith()]) that returns an `integer` or `logical` vector.
+#' @param names A [`character`] vector of row/column names to look for.
+#'  Only used if `select` is `NULL`.
 #' @param ... Further arguments to be passed to `select`.
-#' @return An [`integer`] vector or `NULL`.
+#' @return
+#'  An [`integer`] vector or `NULL` (if `x` does not have row/column names).
 #' @example inst/examples/ex-seek.R
 #' @author N. Frerebeau
 #' @docType methods
@@ -174,7 +177,7 @@ setGeneric(
   def = function(x, ...) standardGeneric("seek_rows")
 )
 
-## Seek ------------------------------------------------------------------------
+## Get -------------------------------------------------------------------------
 #' Get Rows/Columns by Name
 #'
 #' Returns rows/columns selected by name in an array-like object.
@@ -236,13 +239,13 @@ setGeneric(
   def = function(x, ...) standardGeneric("assign_rownames")
 )
 
+## Append ----------------------------------------------------------------------
 #' Convert Row Names to an Explicit Column
 #'
 #' @param x A [`data.frame`].
 #' @param after A length-one [`numeric`] vector specifying a subscript,
 #'  after which the row names are to be appended.
-#' @param var A [`character`] string giving the name of column to use for row
-#'  names.
+#' @param var A [`character`] string giving the name of name of the new column.
 #' @param remove A [`logical`] scalar: should the row names be removed?
 #' @param ... Currently not used.
 #' @example inst/examples/ex-assign.R
@@ -250,17 +253,36 @@ setGeneric(
 #' @author N. Frerebeau
 #' @docType methods
 #' @family data preparation tools
-#' @name append
-#' @rdname append
-NULL
-
-#' @rdname append
 #' @aliases append_rownames-method
 setGeneric(
   name = "append_rownames",
   def = function(x, ...) standardGeneric("append_rownames")
 )
 
+#' Add a (Named) Vector as a Column
+#'
+#' @param x A [`data.frame`].
+#' @param column A (named) `vector`.
+#' @param after A length-one [`numeric`] vector specifying a subscript,
+#'  after which the new column is to be appended.
+#' @param var A [`character`] string giving the name of the new column.
+#' @param ... Currently not used.
+#' @details
+#'  If `column` is named, names will be matched to the row names of `x`. Only
+#'  the first match is retained, and elements of `column` without a match are
+#'  removed. This allows to add as a column a vector whose length is less than
+#'  the number of rows in `x` (`NA`s will be inserted).
+#' @example inst/examples/ex-append.R
+#' @return A [`data.frame`].
+#' @author N. Frerebeau
+#' @docType methods
+#' @family data preparation tools
+#' @aliases append_column-method
+setGeneric(
+  name = "append_column",
+  def = function(x, ...) standardGeneric("append_column")
+)
+
 # Data cleaning ================================================================
 ## NA --------------------------------------------------------------------------
 #' Remove Rows/Columns with Missing Values
@@ -479,8 +501,6 @@ setGeneric(
   def = function(x, ...) standardGeneric("sparsity")
 )
 
-# Data transformation ==========================================================
-
 # Mathematics ==================================================================
 #' Least Common Multiple
 #'
