@@ -13,32 +13,35 @@ setMethod(
     m <- nrow(x)
     p <- ncol(x)
 
-    rows <- ngettext(m, "observation", "observations")
-    cols <- ngettext(p, "variable", "variables")
-
-    msg_tbl <- sprintf("%d %s with %d %s:", m, rows, p, cols)
+    msg_rows <- sprintf(ngettext(m, "%d observation", "%d observations"), m)
+    msg_cols <- sprintf(ngettext(p, "%d variable", "%d variables"), p)
+    msg_tbl <- sprintf("%s, %s:", msg_rows, msg_cols)
 
     ## Missing values
+    n_NA <- sum(count(x, f = is.na))
     m_NA <- sum(detect(x, f = is.na, margin = 1))
     p_NA <- sum(detect(x, f = is.na, margin = 2))
-
-    rows_NA <- ngettext(m_NA, "observation", "observations")
-    cols_NA <- ngettext(p_NA, "variable", "variables")
-
     pc <- label_percent(c(m_NA / m, p_NA / p), digits = 1, trim = TRUE)
-    pc_NA <- sprintf(" (%s)", pc)
 
-    msg_row_NA <- sprintf("%d %s%s containing missing values.", m_NA, rows_NA, pc_NA[[1]])
-    msg_col_NA <- sprintf("%d %s%s containing missing values.", p_NA, cols_NA, pc_NA[[2]])
+    msg_NA <- sprintf(ngettext(n_NA, "\n%d missing value:", "\n%d missing values:"), n_NA)
+
+    rows_NA <- ngettext(m_NA, "%d observation (%s) contains missing values.",
+                        "%d observations (%s) contain missing values.")
+    msg_row_NA <- sprintf(rows_NA, m_NA, pc[[1]])
+
+    cols_NA <- ngettext(p_NA, "%d variable (%s) contains missing values.",
+                        "%d variables (%s) contain missing values.")
+    msg_col_NA <- sprintf(cols_NA, p_NA, pc[[2]])
 
     ## Constant columns
     p_var <- sum(detect(x, f = function(x) is_unique(x), margin = 2))
-    cols_var <- ngettext(p_var, "variable", "variables")
-    msg_col_var <- sprintf("%d %s with no variance.", p_var, cols_var)
+    cols_var <- ngettext(p_var, "%d variable with no variance.",
+                         "%d variables with no variance.")
+    msg_col_var <- sprintf(cols_var, p_var)
 
     ## Sparsity
     spa <- sparsity(x, count = FALSE)
-    msg_spa <- sprintf("%s of numeric values are zero.", label_percent(spa, digits = 1))
+    msg_spa <- sprintf(tr_("%s of numeric values are zero."), label_percent(spa, digits = 1))
 
     ## Variable types
     num <- detect(x, f = is.numeric, margin = 2)
@@ -47,13 +50,13 @@ setMethod(
     n_bin <- sum(bin)
     n_cha <- sum(!num & !bin)
 
-    msg_num <- sprintf("%d numeric %s.", n_num, ngettext(n_num, "variable", "variables"))
-    msg_bin <- sprintf("%d binary %s.", n_bin, ngettext(n_bin, "variable", "variables"))
-    msg_cha <- sprintf("%d categorial %s.", n_cha, ngettext(n_cha, "variable", "variables"))
+    msg_num <- sprintf(ngettext(n_num, "%d numeric variable.", "%d numeric variables."), n_num)
+    msg_bin <- sprintf(ngettext(n_bin, "%d binary variable.", "%d binary variables."), n_bin)
+    msg_cha <- sprintf(ngettext(n_cha, "%d categorial variable.", "%d categorial variables."), n_cha)
 
     cat(msg_tbl, msg_num, msg_cha, msg_bin, sep = "\n* ")
-    cat("\nData checking:", msg_spa, msg_col_var, sep = "\n* ")
-    cat("\nMissing values:", msg_row_NA, msg_col_NA, sep = "\n* ")
+    cat(msg_NA, msg_row_NA, msg_col_NA, sep = "\n* ")
+    cat(tr_("\nData checking:"), msg_spa, msg_col_var, sep = "\n* ")
 
     # tot <- list(
     #   m = m, p = p,
